pub struct SupportStateView {
pub cases: HashMap<String, SupportCaseView>,
pub refresh_call_counts: HashMap<String, usize>,
}Expand description
Serializable view of the entire Support state for one account/region.
Fields
cases: HashMap<String, SupportCaseView>Support cases keyed by case ID.
refresh_call_counts: HashMap<String, usize>Refresh call counts for trusted advisor checks, keyed by check ID.